AutoArchive — AutoArchive Developer Manual (ver. 2.1.0.dev20260309)

# AutoArchive

A simple backup utility.

This package does not provide any public library (API) intended to be imported by 3rd-party programs. All its content and content of its subpackages is the implementation of AutoArchive utility.

## Sub-Packages

- AutoArchive._application
- AutoArchive._infrastructure
- AutoArchive._services
- AutoArchive._ui

## Modules

### starter

class AutoArchive.starter.Starter

  Bases: `object`

  Fires up the show.

  classmethod start(programArgs=['/usr/lib/python-exec/python3.13/sphinx-build', '-b', 'html', '-d', '../../devel/doctrees', '.', '../../devel/html'])

    Initializes and starts the program.

### _meta

`_Meta` class.

class AutoArchive._meta._Meta

  Bases: `object`

  Defines various project metadata like version, license etc.

  COPYRIGHT = 'Copyright (C) 2003 - 2026 Robert Cernansky'
  DESCRIPTION = 'A simple backup utility.'
  LICENSE = 'This program is free software: you can redistribute it and/or modify it under\nthe terms of the GNU General Public License version 3 as published by the Free\nSoftware Foundation.\n\nThis program is distributed in the hope that it will be useful, but WITHOUT ANY\nWARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR\nA PARTICULAR PURPOSE. See the GNU General Public License for more details.\n\nYou should have received a copy of the GNU General Public License along with\nthis program. If not, see <http://www.gnu.org/licenses/>.'
  PACKAGE_NAME = 'autoarchive'
  VERSION = '2.1.0.dev20260309'